pm4py.statistics.traces.generic package
=======================================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   pm4py.statistics.traces.generic.common
   pm4py.statistics.traces.generic.log
   pm4py.statistics.traces.generic.pandas

Module contents
---------------

.. automodule:: pm4py.statistics.traces.generic
   :members:
   :undoc-members:
   :show-inheritance:
